@@ -5,12 +5,48 @@
 #' @param h integer; \code{(h = 1)} (default) Number of periods to forecast. \code{(h = 0)} will return just the interpolated and extrapolated values up to the current month.
 #' @param additional.regressors character; \code{NULL} (default) add more regressors to the base model.  The format must utilize the \code{\link[quantmod]{getSymbols}} format for FRED data, else specify the source.
 #' @param additional.sources character; \code{NULL} (default) specify the \code{source} argument per \code{\link[quantmod]{getSymbols}} for each \code{additional.regressors} specified.
-#' @param specific.regressors integer; \code{NULL} (default) Select individual regressors from the base model per Viole (2020) listed in the References.
+#' @param naive.weights logical; \code{TRUE} (default) Equal weights applied to univariate and multivariate outputs in ensemble.  \code{FALSE} will apply weights based on the number of relevant variables detected. 
+#' @param specific.regressors integer; \code{NULL} (default) Select individual regressors from the base model per Viole (2020) listed in the \code{Note} below.
 #' @param start.date character; \code{"2000-01-03"} (default) Starting date for all data series download.
 #' @param keep.data logical; \code{FALSE} (default) Keeps downloaded variables in a new environment \code{NNSdata}.
 #' @param status logical; \code{TRUE} (default) Prints status update message in console.
 #' @param ncores integer; value specifying the number of cores to be used in the parallelized subroutine \link{NNS.ARMA.optim}. If NULL (default), the number of cores to be used is equal to the number of cores of the machine - 1.
 #'
+#' @note Specific regressors include:
+#' \enumerate{
+#'   \item \code{PAYEMS} -- Payroll Employment
+#'   \item \code{JTSJOL} -- Job Openings
+#'   \item \code{CPIAUCSL} -- Consumer Price Index
+#'   \item \code{DGORDER} -- Durable Goods Orders
+#'   \item \code{RSAFS} -- Retail Sales
+#'   \item \code{UNRATE} -- Unemployment Rate
+#'   \item \code{HOUST} -- Housing Starts
+#'   \item \code{INDPRO} -- Industrial Production
+#'   \item \code{DSPIC96} -- Personal Income
+#'   \item \code{BOPTEXP} -- Exports
+#'   \item \code{BOPTIMP} -- Imports
+#'   \item \code{TTLCONS} -- Construction Spending
+#'   \item \code{IR} -- Import Price Index
+#'   \item \code{CPILFESL} -- Core Consumer Price Index
+#'   \item \code{PCEPILFE} -- Core PCE Price Index
+#'   \item \code{PCEPI} -- PCE Price Index
+#'   \item \code{PERMIT} -- Building Permits
+#'   \item \code{TCU} -- Capacity Utilization Rate
+#'   \item \code{BUSINV} -- Business Inventories
+#'   \item \code{ULCNFB} -- Unit Labor Cost
+#'   \item \code{IQ} -- Export Price Index
+#'   \item \code{GACDISA066MSFRBNY} -- Empire State Mfg Index
+#'   \item \code{GACDFSA066MSFRBPHI} -- Philadelphia Fed Mfg Index
+#'   \item \code{PCEC96} -- Real Consumption Spending
+#'   \item \code{GDPC1} -- Real Gross Domestic Product
+#'   \item \code{ICSA} -- Weekly Unemployment Claims
+#'   \item \code{DGS10} -- 10-year Treasury rates
+#'   \item \code{T10Y2Y} -- 2-10 year Treasury rate spread
+#'   \item \code{WALCL} -- Total Assets
+#'   \item \code{PALLFNFINDEXM} -- Global Price Index of All Commodities
+#'   \item \code{FEDFUNDS} -- Federal Funds Effective Rate
+#'  }
+#' 
 #' @return Returns the following matrices of forecasted variables:
 #' \itemize{
 #'  \item{\code{"interpolated_and_extrapolated"}} Returns a \code{data.frame} of the linear interpolated and \link{NNS.ARMA} extrapolated values to replace \code{NA} values in the original \code{variables} argument.  This is required for working with variables containing different frequencies, e.g. where \code{NA} would be reported for intra-quarterly data when indexed with monthly periods.
@@ -72,6 +108,7 @@
 NNS.nowcast <- function(h = 1,
                         additional.regressors = NULL,
                         additional.sources = NULL,
+                        naive.weights = TRUE,
                         specific.regressors = NULL,
                         start.date = "2000-01-03",
                         keep.data = FALSE,
@@ -85,7 +122,8 @@ NNS.nowcast <- function(h = 1,
                  "BOPTIMP", "TTLCONS", "IR", "CPILFESL", "PCEPILFE",
                  "PCEPI", "PERMIT", "TCU", "BUSINV", "ULCNFB",
                  "IQ", "GACDISA066MSFRBNY", "GACDFSA066MSFRBPHI", "PCEC96", "GDPC1",
-                 "ICSA", "DGS10", "T10Y2Y", "WALCL", "PALLFNFINDEXM", "FEDFUNDS")
+                 "ICSA",
+                  "DGS10", "T10Y2Y", "WALCL", "PALLFNFINDEXM", "FEDFUNDS")
 
   sources <- c(rep("FRED", length(variables)), additional.sources)
   
@@ -93,7 +131,7 @@ NNS.nowcast <- function(h = 1,
 
   symbols <- as.character(unlist(variable_list[, 1]))
   
-  if(!is.null(specific.regressors)) variable_list <- variable_list[symbols%in%specific.regressors, , drop=FALSE]
+  if(!is.null(specific.regressors)) variable_list <- variable_list[symbols%in%symbols[specific.regressors], , drop=FALSE]
 
   symbols <- as.character(unlist(variable_list[, 1]))
   sources <- as.character(unlist(variable_list[, 2]))
@@ -126,8 +164,8 @@ NNS.nowcast <- function(h = 1,
   econ_variables <- Reduce(function(...) merge(..., all=TRUE), raw_econ_variables)[paste0(start.date,"::")]
 
   colnames(econ_variables) <- symbols
-  
+
   options(warn = oldw)
   
-  NNS.VAR(econ_variables, h = h, tau = 12, status = status, ncores = ncores, nowcast = TRUE)
+  NNS.VAR(econ_variables, h = h, tau = 12, status = status, ncores = ncores, nowcast = TRUE, naive.weights = naive.weights)
 }
