@@ -14,7 +14,7 @@ require(rgl)
 require(meboot)
 
 ## ----linear,fig.width=5,fig.height=3,fig.align = "center", warning=FALSE------
-nns = NNS.ARMA(AirPassengers, 
+nns_lin = NNS.ARMA(AirPassengers, 
                h = 44, 
                training.set = 100, 
                method = "lin", 
@@ -22,10 +22,10 @@ nns = NNS.ARMA(AirPassengers,
                seasonal.factor = 12, 
                seasonal.plot = FALSE)
 
-sqrt(mean((nns - tail(AirPassengers, 44)) ^ 2))
+sqrt(mean((nns_lin - tail(AirPassengers, 44)) ^ 2))
 
 ## ----nonlinear,fig.width=5,fig.height=3,fig.align = "center", eval = FALSE----
-#  nns = NNS.ARMA(AirPassengers,
+#  nns_nonlin = NNS.ARMA(AirPassengers,
 #                 h = 44,
 #                 training.set = 100,
 #                 method = "nonlin",
@@ -33,7 +33,7 @@ sqrt(mean((nns - tail(AirPassengers, 44)) ^ 2))
 #                 seasonal.factor = 12,
 #                 seasonal.plot = FALSE)
 #  
-#  sqrt(mean((nns - tail(AirPassengers, 44)) ^ 2))
+#  sqrt(mean((nns_nonlin - tail(AirPassengers, 44)) ^ 2))
 
 ## ----nonlinearres, eval = FALSE-----------------------------------------------
 #  [1] 19.1362
@@ -66,7 +66,7 @@ NNS.seas(AirPassengers, modulo = 12, plot = FALSE)
 #                               seasonal.factor = seq(12, 60, 6),
 #                               obj.fn = expression( sqrt(mean((predicted - actual)^2)) ),
 #                               objective = "min",
-#                               pred.int = .95)
+#                               pred.int = .95, plot = TRUE)
 #  
 #  nns.optimal
 
@@ -80,15 +80,17 @@ NNS.seas(AirPassengers, modulo = 12, plot = FALSE)
 #  [1] "CURRNET METHOD: nonlin"
 #  [1] "COPY LATEST PARAMETERS DIRECTLY FOR NNS.ARMA() IF ERROR:"
 #  [1] "NNS.ARMA(... method =  'nonlin' , seasonal.factor =  c( 12 ) ...)"
-#  [1] "CURRENT nonlin OBJECTIVE FUNCTION = 19.1362358134362"
+#  [1] "CURRENT nonlin OBJECTIVE FUNCTION = 18.7788946994645"
 #  [1] "BEST method = 'nonlin' PATH MEMBER = c( 12 )"
-#  [1] "BEST nonlin OBJECTIVE FUNCTION = 19.1362358134362"
+#  [1] "BEST nonlin OBJECTIVE FUNCTION = 18.7788946994645"
 #  [1] "CURRNET METHOD: both"
 #  [1] "COPY LATEST PARAMETERS DIRECTLY FOR NNS.ARMA() IF ERROR:"
 #  [1] "NNS.ARMA(... method =  'both' , seasonal.factor =  c( 12 ) ...)"
-#  [1] "CURRENT both OBJECTIVE FUNCTION = 26.9572377070982"
+#  [1] "CURRENT both OBJECTIVE FUNCTION = 26.9404229568573"
 #  [1] "BEST method = 'both' PATH MEMBER = c( 12 )"
-#  [1] "BEST both OBJECTIVE FUNCTION = 26.9572377070982"
+#  [1] "BEST both OBJECTIVE FUNCTION = 26.9404229568573"
+#  
+#  
 #  $periods
 #  [1] 12
 #  
@@ -96,7 +98,7 @@ NNS.seas(AirPassengers, modulo = 12, plot = FALSE)
 #  NULL
 #  
 #  $obj.fn
-#  [1] 19.49762
+#  [1] 18.77889
 #  
 #  $method
 #  [1] "nonlin"
@@ -111,38 +113,25 @@ NNS.seas(AirPassengers, modulo = 12, plot = FALSE)
 #  [1] 0
 #  
 #  $errors
-#   [1] -12.0495905 -19.5023885 -18.2981119 -30.4665605 -21.9967015 -16.3628298
-#   [7] -12.6732257  -5.7137170  -2.6001984   2.2792659  17.1994048  24.2420635
-#  [13]   6.6919485  -1.2269250  -8.4029057 -34.4569779   6.9539623  -2.5920976
-#  [19]   4.8338436  18.5863427   1.8098569  -0.3087157  -1.1892791   2.5325891
-#  [25] -22.4687006  -4.9819699 -27.7262972 -52.7041072 -21.5667488 -23.9122298
-#  [31] -23.6982624 -23.0856682 -29.9142644 -27.1628466  12.6507957 -35.1714729
-#  [37] -46.1877025 -34.0820674 -63.4664903 -63.3893474 -35.6270575 -51.0256013
-#  [43] -27.9853043 -23.5848310
+#   [1] -14.47605733 -21.86813452 -19.68680481 -32.74950538 -23.55099666 -17.40139233 -13.70469091  -6.24837561  -2.48949314   2.13237206  16.92258707  23.90974592   4.53920624
+#  [14]  -2.80578226  -8.66505386 -35.95512814   6.15047733  -3.05392579   4.47214630  18.85551669   2.32637841   0.08983381  -1.04028830   2.89582233 -24.22859693  -6.13584252
+#  [27] -27.38320978 -53.70280267 -21.86253259 -23.90679863 -23.77369245 -22.36041401 -29.22056474 -26.31507238  12.93035387 -34.59586321 -47.79031322 -34.85559482 -62.85716413
+#  [40] -64.07451099 -35.67072562 -50.91910417 -27.91240080 -22.72623962
 #  
 #  $results
-#   [1] 354.2580 421.2452 462.4395 453.0669 395.8280 338.4172 301.1178 338.6083
-#   [9] 347.7440 330.7530 393.0655 383.2619 390.9250 468.8563 511.8161 501.4936
-#  [17] 436.7415 370.9154 331.3098 371.0849 380.7716 361.0259 430.2580 418.6685
-#  [25] 427.7316 516.8815 561.5732 550.3086 478.0325 403.7194 361.7944 403.9807
-#  [33] 413.6136 390.9586 467.3674 453.9804 464.4469 564.6356 611.0813 598.8694
-#  [41] 519.0765 436.3233 392.0875 436.6022
+#   [1] 338.5400 405.6487 448.7971 437.6360 381.8544 325.4751 288.1899 326.6740 337.1004 319.5942 381.6468 371.7323 373.1716 452.1286 498.6929 485.0008 422.3997 357.9051
+#  [19] 318.5071 360.0295 371.1142 350.8923 419.5388 408.2967 408.8936 499.6842 549.5283 533.5434 464.0692 391.2918 349.2869 394.1562 404.3549 381.6612 456.5031 443.9546
+#  [37] 443.9982 546.2672 599.0085 581.0612 504.6510 423.7409 379.3403 427.2016
 #  
 #  $lower.pred.int
-#   [1] 291.6700 358.6573 399.8515 390.4789 333.2401 275.8292 238.5299 276.0203
-#   [9] 285.1561 268.1650 330.4775 320.6740 328.3370 406.2684 449.2281 438.9056
-#  [17] 374.1535 308.3275 268.7218 308.4970 318.1836 298.4380 367.6701 356.0805
-#  [25] 365.1437 454.2935 498.9853 487.7206 415.4446 341.1314 299.2065 341.3928
-#  [33] 351.0256 328.3706 404.7794 391.3924 401.8589 502.0477 548.4933 536.2814
-#  [41] 456.4885 373.7353 329.4996 374.0142
+#   [1] 287.2344 354.3431 397.4915 386.3304 330.5488 274.1695 236.8843 275.3684 285.7949 268.2886 330.3413 320.4267 321.8661 400.8231 447.3873 433.6952 371.0941 306.5995
+#  [19] 267.2016 308.7239 319.8086 299.5867 368.2332 356.9912 357.5880 448.3786 498.2227 482.2379 412.7636 339.9862 297.9813 342.8507 353.0493 330.3556 405.1975 392.6490
+#  [37] 392.6926 494.9616 547.7030 529.7556 453.3454 372.4353 328.0347 375.8961
 #  
 #  $upper.pred.int
-#   [1] 416.8459 483.8332 525.0274 515.6548 458.4160 401.0052 363.7058 401.1962
-#   [9] 410.3320 393.3409 455.6534 445.8499 453.5129 531.4443 574.4040 564.0815
-#  [17] 499.3294 433.5034 393.8977 433.6729 443.3595 423.6139 492.8460 481.2564
-#  [25] 490.3196 579.4694 624.1612 612.8965 540.6205 466.3074 424.3824 466.5687
-#  [33] 476.2015 453.5465 529.9553 516.5683 527.0349 627.2236 673.6692 661.4573
-#  [41] 581.6644 498.9112 454.6755 499.1901
+#   [1] 368.1156 435.2243 478.3727 467.2115 411.4300 355.0506 317.7655 356.2495 366.6760 349.1697 411.2224 401.3078 402.7472 481.7042 528.2685 514.5763 451.9753 387.4807
+#  [19] 348.0827 389.6050 400.6897 380.4679 449.1144 437.8723 438.4692 529.2597 579.1039 563.1190 493.6448 420.8674 378.8625 423.7318 433.9305 411.2367 486.0786 473.5301
+#  [37] 473.5738 575.8427 628.5841 610.6368 534.2265 453.3165 408.9159 456.7772
 
 ## ----optimsubs, echo = FALSE--------------------------------------------------
 nns.optimal = list()
@@ -154,25 +143,12 @@ nns.optimal$results = c(354.2580, 421.2452, 462.4395, 453.0669, 395.8280, 338.41
 
 nns.optimal$bias.shift = 0
 
-## ----best optim2, eval=TRUE---------------------------------------------------
-sqrt(mean((nns.optimal$results - tail(AirPassengers, 44)) ^ 2))
-
-## ----best optim3, eval=TRUE---------------------------------------------------
-sqrt(mean((nns+nns.optimal$bias.shift - tail(AirPassengers, 44)) ^ 2))
-
-## ----neg, eval=TRUE-----------------------------------------------------------
-nns <- pmax(0, nns + nns.optimal$bias.shift)
-sqrt(mean((nns - tail(AirPassengers, 44)) ^ 2))
-
 ## ----extension,results='hide',fig.width=5,fig.height=3,fig.align = "center", eval=FALSE----
-#  NNS.ARMA(AirPassengers,
-#           h = 50,
-#           pred.int = .95,
-#           seasonal.factor = nns.optimal$periods,
-#           method  = nns.optimal$method,
-#           weights = nns.optimal$weights,
-#           shrink = nns.optimal$shrink,
-#           plot = TRUE, seasonal.plot = FALSE) + nns.optimal$bias.shift
+#  NNS.ARMA.optim(AirPassengers,
+#                  seasonal.factor = seq(12, 60, 6),
+#                  obj.fn = expression( sqrt(mean((predicted - actual)^2)) ),
+#                  objective = "min",
+#                  pred.int = .95, h = 50, plot = TRUE)
 
 ## ----threads, echo = FALSE----------------------------------------------------
 Sys.setenv("OMP_THREAD_LIMIT" = "")
